"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
class HttpClient {
    constructor(config) {
        this.USER_AGENT_HEADER = 'User-Agent';
        config.headers = config.headers || {};
        this.addUserAgentHeader(config.headers);
        this._axiosInstance = axios_1.default.create({
            baseURL: config.serverUrl,
            headers: config.headers,
            proxy: this.getAxiosProxyConfig(config.proxy)
        });
        this._basicAuth = {
            username: config.username,
            password: config.password
        };
    }
    async doRequest(requestParams) {
        const { data } = await this._axiosInstance(requestParams);
        return data;
    }
    async doAuthRequest(requestParams) {
        requestParams.auth = this._basicAuth;
        return this.doRequest(requestParams);
    }
    addUserAgentHeader(headers) {
        if (!headers[this.USER_AGENT_HEADER]) {
            headers[this.USER_AGENT_HEADER] = 'jfrog-xray-client';
        }
    }
    /**
     * @param proxyConfig - Receives on of the three:
     * 1. IProxyConfig to use specific proxy config.
     * 2. 'false' to disable proxy.
     * 3. 'undefined' to use environment variables if exist.
     *
     * @returns AxiosProxyConfig to use specific proxy config, false to disable proxy or undefined to use environment.
     */
    getAxiosProxyConfig(proxyConfig) {
        // Return false to disable proxy or undefined to use default environment variables.
        if (!proxyConfig) {
            return proxyConfig;
        }
        // Return undefined to use default environment variables.
        const proxyHost = proxyConfig.host;
        const proxyPort = proxyConfig.port;
        if (!proxyHost && !proxyPort) {
            return undefined;
        }
        return {
            host: proxyConfig.host,
            port: proxyConfig.port,
            protocol: proxyConfig.protocol
        };
    }
}
exports.HttpClient = HttpClient;
//# sourceMappingURL=HttpClient.js.map